@@ -7,5 +7,6 @@ require 'specinfra/backend/cmd'
 require 'specinfra/backend/docker'
 require 'specinfra/backend/lxc'
 require 'specinfra/backend/winrm'
-require 'specinfra/backend/shellscript'
+require 'specinfra/backend/shell_script'
 require 'specinfra/backend/dockerfile'
+require 'specinfra/backend/telnet'
