@@ -1,13 +1,6 @@
 require 'specinfra/helper/os'
-require 'specinfra/helper/detect_os'
-
-require 'specinfra/helper/backend'
-include SpecInfra::Helper::Backend
-
 require 'specinfra/helper/docker'
 require 'specinfra/helper/lxc'
-
 require 'specinfra/helper/configuration'
-
 require 'specinfra/helper/properties'
-include SpecInfra::Helper::Properties
+require 'specinfra/helper/host_inventory'
