@@ -5,10 +5,10 @@ RSpec.configure do |c|
 end
 
 describe RSpec.configuration.path do
-  it { should eq SpecInfra.configuration.path }
+  it { should eq Specinfra.configuration.path }
 end
 
-SpecInfra.configuration.os = 'foo'
-describe SpecInfra.configuration.os do
+Specinfra.configuration.os = 'foo'
+describe Specinfra.configuration.os do
   it { should eq 'foo' }
 end
